@@ -197,8 +197,6 @@ class MyFormatter(logging.Formatter):
  
     def format(self, record):
         t=logging.Formatter.format(self, record)
-        return t
-        # ASX
         if isinstance(t, unicode):
             t=t.encode(self.encoding, 'replace')
         return t
@@ -221,7 +219,7 @@ def main():
         ftpd.ftpmain(args)
         sys.exit(0)
     
-    parser=parser=OptionParser(version='%%prog %s' % __version__ )
+    parser=OptionParser(version='%%prog %s' % __version__ )
     parser.set_usage('%prog [options] command [job..]\n\n'
                      '\tcommand in "backup", "check", "checkmail"\n\n'
                      '\tuse "ftp" in first place to start buil-in ftp server,\n'
